@@ -12,5 +12,5 @@ class HeartbeatEvent(BaseModel):
     namespace: str = Field("namespace")
     service_name: str = Field("service_name")
     host_ip: str = Field("0.0.0.0")
-    hostname: str = Field("hostname")
+    host_name: str = Field("host_name")
     timestamp: int = Field(0)
