@@ -29,6 +29,6 @@ class DispatchClient:
         result = r.blpop(reply_to, timeout=timeout)
         if result and result[0] == reply_to:
             response = DispatchResponseModel.parse_obj(json.loads(result[1]))
-            if response.correlation_id == correlation_id and response.status == DispatchResponseStatus.OK:
-                return response.data
-        return None
+            if response.correlation_id == correlation_id:
+                return response
+        return DispatchResponseModel(status=DispatchResponseStatus.NO_RESPONSE_ERROR, data='Failed to get response from server')
